@@ -4,7 +4,7 @@
 * acp_board [Deutsch — Sie]
 *
 * @package language
-* @version $Id: board.php 568 2011-06-17 20:23:47Z philippk $
+* @version $Id: board.php 581 2011-11-22 19:15:46Z philippk $
 * @copyright (c) 2005 phpBB Group; 2006 phpBB.de
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -56,7 +56,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'Zeitzone für Gäste',
 	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Zeitzone, die für Benutzer verwendet wird, die nicht angemeldet sind (Gäste, Bots). Angemeldete Benutzer legen ihre Zeitzone während der Registrierung fest und können sie im persönlichen Bereich ändern.',
 	'WARNINGS_EXPIRE'				=> 'Gültigkeit von Verwarnungen',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Die Anzahl der Tage, nach denen eine Verwarnung automatisch aus dem Benutzer-Profil gelöscht wird.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Die Anzahl der Tage, nach denen eine Verwarnung automatisch aus dem Benutzer-Profil gelöscht wird. Um Verwarnungen dauerhaft zu machen, stellen Sie als Wert 0 ein.',
 ));
 
 // Board Features
@@ -177,7 +177,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Maximale Anzahl an Links pro Beitrag',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Maximale Anzahl von Links in einem Beitrag. Um keine Begrenzung festzulegen, stellen Sie als Wert 0 ein.',
 	'MIN_CHAR_LIMIT'				=> 'Minimale Anzahl von Zeichen pro Beitrag/Nachricht',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Die minimale Anzahl von Zeichen, die ein Benutzer in einem Beitrag/einer Nachricht mindestens eingeben muss.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Die minimale Anzahl von Zeichen, die ein Benutzer in einem Beitrag/einer Nachricht mindestens eingeben muss. Der Wert muss 1 oder größer sein.',
 	'POSTING'						=> 'Beiträge schreiben',
 	'POSTS_PER_PAGE'				=> 'Beiträge pro Seite',
 	'QUOTE_DEPTH_LIMIT'				=> 'Maximale Tiefe verschachtelter Zitate',
