@@ -4,7 +4,7 @@
 * common [Deutsch — Sie]
 *
 * @package language
-* @version $Id: common.php 567 2011-06-16 20:29:06Z philippk $
+* @version $Id: common.php 582 2011-11-25 20:57:11Z philippk $
 * @copyright (c) 2005 phpBB Group; 2006 phpBB.de
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -46,7 +46,7 @@ $lang = array_merge($lang, array(
 	'TRANSLATION_INFO'	=> 'Deutsche Übersetzung durch <a href="http://www.phpbb.de/">phpBB.de</a>',
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|j. M Y|', // 1. Jan 2007 (ggf. mit relativen Angaben)
-	'USER_LANG'			=> 'de',
+	'USER_LANG'			=> 'de-x-sie',
 
 	'1_DAY'			=> '1 Tag',
 	'1_MONTH'		=> '1 Monat',
@@ -168,6 +168,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Sie müssen einen Betreff angeben, wenn Sie eine neue Nachricht verfassen möchten.',
 	'ENABLED'							=> 'Aktiviert',
 	'ENCLOSURE'							=> 'Texterkennungszeichen',
+	'ENTER_USERNAME'					=> 'Einen Benutzernamen angeben',
 	'ERR_CHANGING_DIRECTORY'			=> 'Das Verzeichnis konnte nicht gewechselt werden.',
 	'ERR_CONNECTING_SERVER'				=> 'Fehler beim Verbindungsaufbau zum Server.',
 	'ERR_JAB_AUTH'						=> 'Die Anmeldung am Jabber-Server war nicht erfolgreich.',
@@ -203,6 +204,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Die Forumsregeln lesen',
 	'FROM'					=> 'von',
 	'FSOCK_DISABLED'		=> 'Dieser Vorgang kann nicht abgeschlossen werden, da die <var>fsockopen</var>-Funktion deaktiviert wurde oder weil der angegebene Server nicht gefunden werden konnte.',
+	'FSOCK_TIMEOUT'			=> 'Beim Lesen des Datenstroms ist eine Zeitüberschreitung aufgetreten.',
 
 	'FTP_FSOCK_HOST'				=> 'FTP-Server',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'FTP-Server, auf dem sich Ihre Website befindet.',
@@ -655,6 +657,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> ungelesene Nachrichten',
 	'UNREAD_POST'			=> 'Ungelesener Beitrag',
 	'UNREAD_POSTS'			=> 'Ungelesene Beiträge',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Sind Sie sich sicher, dass Sie dieses Forum nicht mehr beobachten möchten?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Sind Sie sich sicher, dass Sie das Forum „%s“ nicht mehr beobachten möchten?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Sind Sie sich sicher, dass Sie dieses Thema nicht mehr beobachten möchten?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Sind Sie sich sicher, dass Sie das Thema „%s“ nicht mehr beobachten möchten?',
 	'UNWATCHED_FORUMS'			=> 'Sie beobachten die ausgewählten Foren nicht mehr.',
 	'UNWATCHED_TOPICS'			=> 'Sie beobachten die ausgewählten Themen nicht mehr.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Sie beobachten die ausgewählten Elemente nicht mehr.',
@@ -703,6 +709,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Verwarnungen',
 	'WARN_USER'			=> 'Benutzer verwarnen',
+	'WATCH_FORUM_CONFIRM'	=> 'Sind Sie sich sicher, dass Sie dieses Forum beobachten möchten?',
+	'WATCH_FORUM_DETAILED'	=> 'Sind Sie sich sicher, dass Sie das Forum „%s“ beobachten möchten?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Sind Sie sich sicher, dass Sie dieses Thema beobachten möchten?',
+	'WATCH_TOPIC_DETAILED'	=> 'Sind Sie sich sicher, dass Sie das Thema „%s“ beobachten möchten?',
 	'WELCOME_SUBJECT'	=> 'Willkommen auf %s',
 	'WEBSITE'			=> 'Website',
 	'WHOIS'				=> 'Whois',
