@@ -4,7 +4,7 @@
 * ucp [Deutsch — Sie]
 *
 * @package language
-* @version $Id: ucp.php 567 2011-06-16 20:29:06Z philippk $
+* @version $Id: ucp.php 582 2011-11-25 20:57:11Z philippk $
 * @copyright (c) 2005 phpBB Group; 2006 phpBB.de
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -179,6 +179,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'Aktuelles Bild',
 	'CURRENT_PASSWORD'			=> 'Aktuelles Passwort',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Sie müssen Ihr aktuelles Passwort bestätigen, wenn Sie es ändern oder Ihren Benutzernamen oder Ihre E-Mail-Adresse abändern möchten.',
+	'CUR_PASSWORD_EMPTY'		=> 'Sie haben Ihr aktuelles Passwort nicht angegeben.',
 	'CUR_PASSWORD_ERROR'		=> 'Das angegebene aktuelle Passwort ist fehlerhaft.',
 	'CUSTOM_DATEFORMAT'			=> 'Eigenes …',
 
@@ -309,9 +310,11 @@ $lang = array_merge($lang, array(
 	'MOVE_TO_FOLDER'				=> 'In Ordner verschieben',
 	'MOVE_UP'						=> 'Nach oben',
 
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Sie haben Ihr Passwort nicht bestätigt.',
 	'NEW_EMAIL_ERROR'			=> 'Die angegebenen E-Mail-Adressen stimmten nicht überein.',
 	'NEW_FOLDER_NAME'			=> 'Neuer Name des Ordners',
 	'NEW_PASSWORD'				=> 'Neues Passwort',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Sie haben das Passwort nicht bestätigt.',
 	'NEW_PASSWORD_ERROR'		=> 'Das angegebene Passwort stimmte nicht mit seiner Bestätigung überein.',
 	'NOTIFY_METHOD'				=> 'Benachrichtigungs-Methode',
 	'NOTIFY_METHOD_BOTH'		=> 'Beide',
